@@ -304,9 +304,4 @@ class Calculator():
         else:
             zScore=float(zScore.quantize(D('0.01')))
             
-        return zScore
-
-
-
-cal=Calculator()
-print(cal.zScore_withclass(weight="7.853",age_in_months="16",sex="M",height="73",muac="12.5"))
+        return zScore
\ No newline at end of file
